# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import div_rotation_transformation, div_translation_transformation


DivTransformation = Union[
    div_rotation_transformation.DivRotationTransformation,
    div_translation_transformation.DivTranslationTransformation,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action


# Sends variables from the container by link. Data sending configuration can be
# defined by the host app. By default, variables are sent as JSON in the request
# body using the POST method.
class DivActionSubmit(BaseDiv):

    def __init__(
        self, *,
        type: str = "submit",
        container_id: typing.Optional[typing.Union[Expr, str]] = None,
        on_fail_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        on_success_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        request: typing.Optional[DivActionSubmitRequest] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            container_id=container_id,
            on_fail_actions=on_fail_actions,
            on_success_actions=on_success_actions,
            request=request,
            **kwargs,
        )

    type: str = Field(default="submit")
    container_id: typing.Union[Expr, str] = Field(
        description="ID of the container with the variables to be sent.",
    )
    on_fail_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions when sending data is unsuccessful.",
    )
    on_success_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions when sending data is successful.",
    )
    request: DivActionSubmitRequest = Field(
        description=(
            "HTTP request parameters for configuring the sending of "
            "data."
        ),
    )


# HTTP request parameters for configuring the sending of data.
class DivActionSubmitRequest(BaseDiv):

    def __init__(
        self, *,
        headers: typing.Optional[typing.Sequence[RequestHeader]] = None,
        method: typing.Optional[typing.Union[Expr, RequestMethod]] = None,
        url: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            headers=headers,
            method=method,
            url=url,
            **kwargs,
        )

    headers: typing.Optional[typing.Sequence[RequestHeader]] = Field(
        description=(
            "HTTP request headers. Please note that DivKit does not "
            "clean duplicate headers,which can lead to errors in request "
            "processing. Keep this in mind when assemblingactions with "
            "complex JSON-builders."
        ),
    )
    method: typing.Optional[typing.Union[Expr, RequestMethod]] = Field(
        description="HTTP request method.",
    )
    url: typing.Union[Expr, str] = Field(
        format="uri", 
        description="Link for sending data from the container.",
    )


class RequestMethod(str, enum.Enum):
    GET = "get"
    POST = "post"
    PUT = "put"
    PATCH = "patch"
    DELETE = "delete"
    HEAD = "head"
    OPTIONS = "options"


class RequestHeader(BaseDiv):

    def __init__(
        self, *,
        name: typing.Optional[typing.Union[Expr, str]] = None,
        value: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            name=name,
            value=value,
            **kwargs,
        )

    name: typing.Union[Expr, str] = Field(
    )
    value: typing.Union[Expr, str] = Field(
    )


RequestHeader.update_forward_refs()


DivActionSubmitRequest.update_forward_refs()


DivActionSubmit.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_appearance_transition


# A set of animations to be applied simultaneously.
class DivAppearanceSetTransition(BaseDiv):

    def __init__(
        self, *,
        type: str = "set",
        items: typing.Optional[typing.Sequence[div_appearance_transition.DivAppearanceTransition]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            items=items,
            **kwargs,
        )

    type: str = Field(default="set")
    items: typing.Sequence[div_appearance_transition.DivAppearanceTransition] = Field(
        min_items=1, 
        description="An array of animations.",
    )


DivAppearanceSetTransition.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivInputValidatorBase(BaseDiv):

    def __init__(
        self, *,
        allow_empty: typing.Optional[typing.Union[Expr, bool]] = None,
        label_id: typing.Optional[typing.Union[Expr, str]] = None,
        variable: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            allow_empty=allow_empty,
            label_id=label_id,
            variable=variable,
            **kwargs,
        )

    allow_empty: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Determines whether the empty field value is valid.",
    )
    label_id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "ID of the text element containing the error message. The "
            "message will also beused for providing access."
        ),
    )
    variable: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "The name of the variable that stores the calculation "
            "results."
        ),
    )


DivInputValidatorBase.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div, div_action


# Edits the element.
class DivPatch(BaseDiv):

    def __init__(
        self, *,
        changes: typing.Optional[typing.Sequence[DivPatchChange]] = None,
        mode: typing.Optional[typing.Union[Expr, DivPatchMode]] = None,
        on_applied_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        on_failed_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            changes=changes,
            mode=mode,
            on_applied_actions=on_applied_actions,
            on_failed_actions=on_failed_actions,
            **kwargs,
        )

    changes: typing.Sequence[DivPatchChange] = Field(
        min_items=1, 
        description="Element changes.",
    )
    mode: typing.Optional[typing.Union[Expr, DivPatchMode]] = Field(
        description=(
            "Procedure for applying changes:`transactional` — if an "
            "error occurs duringapplication of at least one element, the "
            "changes aren\'t applied.`partial` — allpossible changes are "
            "applied. If there are errors, they are reported."
        ),
    )
    on_applied_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions to perform after changes are applied.",
    )
    on_failed_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions to perform if there’s an error when applying "
            "changes in transaction mode."
        ),
    )


class DivPatchMode(str, enum.Enum):
    TRANSACTIONAL = "transactional"
    PARTIAL = "partial"


class DivPatchChange(BaseDiv):

    def __init__(
        self, *,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        items: typing.Optional[typing.Sequence[div.Div]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            id=id,
            items=items,
            **kwargs,
        )

    id: typing.Union[Expr, str] = Field(
        description="ID of an element to be replaced or removed.",
    )
    items: typing.Optional[typing.Sequence[div.Div]] = Field(
        description=(
            "Elements to be inserted. If the parameter isn\'t specified, "
            "the element will beremoved."
        ),
    )


DivPatchChange.update_forward_refs()


DivPatch.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Specifies the position measured in `dp` from the container start as the scrolling
# end position. Only applies in `gallery`.
class OffsetDestination(BaseDiv):

    def __init__(
        self, *,
        type: str = "offset",
        value: typing.Optional[typing.Union[Expr, int]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            value=value,
            **kwargs,
        )

    type: str = Field(default="offset")
    value: typing.Union[Expr, int] = Field(
        description="Position measured in `dp`.",
    )


OffsetDestination.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Solid stroke style.
class DivStrokeStyleSolid(BaseDiv):

    def __init__(
        self, *,
        type: str = "solid",
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            **kwargs,
        )

    type: str = Field(default="solid")


DivStrokeStyleSolid.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_size_unit


class DivSizeUnitValue(BaseDiv):

    def __init__(
        self, *,
        unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = None,
        value: typing.Optional[typing.Union[Expr, int]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            unit=unit,
            value=value,
            **kwargs,
        )

    unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = Field(
        description=(
            "Unit of measurement:`px` — a physical pixel.`dp` — a "
            "logical pixel that doesn\'tdepend on screen density.`sp` — "
            "a logical pixel that depends on the font size ona device. "
            "Specify height in `sp`. Only available on Android."
        ),
    )
    value: typing.Union[Expr, int] = Field(
        description="Element size.",
    )


DivSizeUnitValue.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_radial_gradient_center, div_radial_gradient_radius


# Radial gradient.
class DivRadialGradient(BaseDiv):

    def __init__(
        self, *,
        type: str = "radial_gradient",
        center_x: typing.Optional[div_radial_gradient_center.DivRadialGradientCenter] = None,
        center_y: typing.Optional[div_radial_gradient_center.DivRadialGradientCenter] = None,
        color_map: typing.Optional[typing.Sequence[DivRadialGradientColorPoint]] = None,
        colors: typing.Optional[typing.Sequence[typing.Union[Expr, str]]] = None,
        radius: typing.Optional[div_radial_gradient_radius.DivRadialGradientRadius] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            center_x=center_x,
            center_y=center_y,
            color_map=color_map,
            colors=colors,
            radius=radius,
            **kwargs,
        )

    type: str = Field(default="radial_gradient")
    center_x: typing.Optional[div_radial_gradient_center.DivRadialGradientCenter] = Field(
        description=(
            "Shift of the central point of the gradient relative to the "
            "left edge along the Xaxis."
        ),
    )
    center_y: typing.Optional[div_radial_gradient_center.DivRadialGradientCenter] = Field(
        description=(
            "Shift of the central point of the gradient relative to the "
            "top edge along the Yaxis."
        ),
    )
    color_map: typing.Optional[typing.Sequence[DivRadialGradientColorPoint]] = Field(
        min_items=2, 
        description=(
            "Colors and positions of gradient points. When using this "
            "parameter, the `colors`parameter is ignored."
        ),
    )
    colors: typing.Optional[typing.Sequence[typing.Union[Expr, str]]] = Field(
        min_items=2, 
        description=(
            "Colors. Gradient points are located at an equal distance "
            "from each other."
        ),
    )
    radius: typing.Optional[div_radial_gradient_radius.DivRadialGradientRadius] = Field(
        description="Radius of the gradient transition.",
    )


# Describes color at particular gradient position.
class DivRadialGradientColorPoint(BaseDiv):

    def __init__(
        self, *,
        color: typing.Optional[typing.Union[Expr, str]] = None,
        position: typing.Optional[typing.Union[Expr, float]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            color=color,
            position=position,
            **kwargs,
        )

    color: typing.Union[Expr, str] = Field(
        format="color", 
        description="Gradient color corresponding to gradient point.",
    )
    position: typing.Union[Expr, float] = Field(
        description="The position of the gradient point.",
    )


DivRadialGradientColorPoint.update_forward_refs()


DivRadialGradient.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_shape, div_stroke


# Drawable of a simple geometric shape.
class DivShapeDrawable(BaseDiv):

    def __init__(
        self, *,
        type: str = "shape_drawable",
        color: typing.Optional[typing.Union[Expr, str]] = None,
        shape: typing.Optional[div_shape.DivShape] = None,
        stroke: typing.Optional[div_stroke.DivStroke] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            color=color,
            shape=shape,
            stroke=stroke,
            **kwargs,
        )

    type: str = Field(default="shape_drawable")
    color: typing.Union[Expr, str] = Field(
        format="color", 
        description="Fill color. @deprecated",
    )
    shape: div_shape.DivShape = Field(
        description="Shape.",
    )
    stroke: typing.Optional[div_stroke.DivStroke] = Field(
        description="Stroke style. @deprecated",
    )


DivShapeDrawable.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Accessibility settings.
class DivAccessibility(BaseDiv):

    def __init__(
        self, *,
        description: typing.Optional[typing.Union[Expr, str]] = None,
        hint: typing.Optional[typing.Union[Expr, str]] = None,
        is_checked: typing.Optional[typing.Union[Expr, bool]] = None,
        mode: typing.Optional[typing.Union[Expr, DivAccessibilityMode]] = None,
        mute_after_action: typing.Optional[typing.Union[Expr, bool]] = None,
        state_description: typing.Optional[typing.Union[Expr, str]] = None,
        type: typing.Optional[typing.Union[Expr, DivAccessibilityType]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            description=description,
            hint=hint,
            is_checked=is_checked,
            mode=mode,
            mute_after_action=mute_after_action,
            state_description=state_description,
            type=type,
            **kwargs,
        )

    description: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Element description. It is used as the main description for "
            "screen readingapplications."
        ),
    )
    hint: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "A tooltip of what will happen during interaction. If Speak "
            "Hints is enabled inthe VoiceOver settings on iOS, a tooltip "
            "is played after `description`."
        ),
    )
    is_checked: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Shows the current status of the checkbox or toggle: `true` "
            "means it\'s selected,`false` means it isn\'t selected."
        ),
    )
    mode: typing.Optional[typing.Union[Expr, DivAccessibilityMode]] = Field(
        description=(
            "The way the accessibility tree is organized. In the `merge` "
            "mode theaccessibility service perceives an element together "
            "with a subtree as a whole. Inthe `exclude` mode an element "
            "together with a subtree isn\'t available foraccessibility."
        ),
    )
    mute_after_action: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Mutes the screen reader sound after interacting with the "
            "element."
        ),
    )
    state_description: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Description of the current state of an element. For "
            "example, in the descriptionyou can specify a selected date "
            "for a date selection element and an on/off statefor a "
            "switch."
        ),
    )
    type: typing.Optional[typing.Union[Expr, DivAccessibilityType]] = Field(
        description=(
            "Element role. Used to correctly identify an element by the "
            "accessibility service.For example, the `list` element is "
            "used to group list elements into one element."
        ),
    )


class DivAccessibilityMode(str, enum.Enum):
    DEFAULT = "default"
    MERGE = "merge"
    EXCLUDE = "exclude"


class DivAccessibilityType(str, enum.Enum):
    NONE = "none"
    BUTTON = "button"
    IMAGE = "image"
    TEXT = "text"
    EDIT_TEXT = "edit_text"
    HEADER = "header"
    TAB_BAR = "tab_bar"
    LIST = "list"
    SELECT = "select"
    CHECKBOX = "checkbox"
    RADIO = "radio"
    AUTO = "auto"


DivAccessibility.update_forward_refs()
